@@ -1,4 +1,5 @@
-from django.db import migrations, models
+from django.db import migrations
+from django.db import models
 
 
 class Migration(migrations.Migration):
@@ -10,8 +11,12 @@ class Migration(migrations.Migration):
     ]
 
     operations = [
-        migrations.AlterModelTable(name="image", table="wiki_images_image",),
         migrations.AlterModelTable(
-            name="imagerevision", table="wiki_images_imagerevision",
+            name="image",
+            table="wiki_images_image",
+        ),
+        migrations.AlterModelTable(
+            name="imagerevision",
+            table="wiki_images_imagerevision",
         ),
     ]
